==> amity-sdk-7.5.0-sources.jar: main/com/ekoapp/ekosdk/internal/data/EkoDatabase.java <==
package com.ekoapp.ekosdk.internal.data;

import android.content.Context;

import androidx.room.Database;
import androidx.room.TypeConverters;

import com.amity.socialcloud.sdk.api.core.encryption.AmityDBEncryption;
import com.amity.socialcloud.sdk.infra.db.DBEncryptionUtils;
import com.amity.socialcloud.sdk.log.AmityLog;
import com.ekoapp.ekosdk.internal.data.converter.DateTimeTypeConverter;
import com.ekoapp.ekosdk.internal.data.converter.EkoPushConfigStateConverter;
import com.ekoapp.ekosdk.internal.data.dao.AmityUploadUrlDao;
import com.ekoapp.ekosdk.internal.data.dao.EkoAccountDao;
import com.ekoapp.ekosdk.internal.data.dao.EkoApiKeyDao;
import com.ekoapp.ekosdk.internal.data.dao.EkoBaiduTokenDao;
import com.ekoapp.ekosdk.internal.data.dao.EkoFcmTokenDao;
import com.ekoapp.ekosdk.internal.data.dao.EkoHttpUrlDao;
import com.ekoapp.ekosdk.internal.data.dao.EkoMqttUrlDao;
import com.ekoapp.ekosdk.internal.data.dao.EkoPushConfigDao;
import com.ekoapp.ekosdk.internal.data.model.AmityUploadUrl;
import com.ekoapp.ekosdk.internal.data.model.EkoAccount;
import com.ekoapp.ekosdk.internal.data.model.EkoApiKey;
import com.ekoapp.ekosdk.internal.data.model.EkoBaiduToken;
import com.ekoapp.ekosdk.internal.data.model.EkoFcmToken;
import com.ekoapp.ekosdk.internal.data.model.EkoHttpUrl;
import com.ekoapp.ekosdk.internal.data.model.EkoMqttUrl;
import com.ekoapp.ekosdk.internal.data.model.EkoPushConfig;

import java.io.File;

@Database(
        version = 10,
        entities = {
                EkoAccount.class,
                EkoApiKey.class,
                EkoFcmToken.class,
                EkoBaiduToken.class,
                EkoPushConfig.class,
                EkoHttpUrl.class,
                EkoMqttUrl.class,
                AmityUploadUrl.class
        })
@TypeConverters({
        EkoPushConfigStateConverter.class,
        DateTimeTypeConverter.class
})
public abstract class EkoDatabase extends BaseRoomDatabase {

    private static EkoDatabase ekoDatabase;
    private static final String AUTH_DB_NAME = "eko";

    public static synchronized void init(
            Context context,
            AmityDBEncryption dbEncryption
    ) {
        final File dbFile = context.getDatabasePath(AUTH_DB_NAME);
        final DBEncryptionUtils.State state =  DBEncryptionUtils.INSTANCE.getDatabaseState(context, dbFile);

        if (dbEncryption instanceof AmityDBEncryption.AUTH
                || dbEncryption instanceof AmityDBEncryption.ALL) {

            if(state == DBEncryptionUtils.State.ENCRYPTED) {
                final boolean hasCorrectPassPhrase =
                        DBEncryptionUtils.INSTANCE.isPassPhraseCorrect(context, dbFile, dbEncryption.getAuthDBKey());
                if(!hasCorrectPassPhrase) {
                    AmityLog.INSTANCE.tag("amityEncryption").d("re-creating auth file with new key");
                    dbFile.delete();
                }
            } else if(state == DBEncryptionUtils.State.UNENCRYPTED) {
                AmityLog.INSTANCE.tag("amityEncryption").d("re-creating auth file with encryption");
                DBEncryptionUtils.INSTANCE.encrypt(context, dbFile, dbEncryption.getAuthDBKey());
            }

        } else { // case AmityDBEncryption.NONE
            if(state == DBEncryptionUtils.State.ENCRYPTED) {
                AmityLog.INSTANCE.tag("amityEncryption").d("re-creating auth file without encryption");
                dbFile.delete();
            } else if(state == DBEncryptionUtils.State.UNENCRYPTED && ekoDatabase != null) {
                // do not re-create database, if UNENCRYPTED db is already created
                return;
            }
        }

        ekoDatabase = BaseRoomDatabase.init(
                context,
                EkoDatabase.class,
                AUTH_DB_NAME,
                ekoDatabase,
                true,
                dbEncryption.getAuthDBKey()
        );
    }

    public static EkoDatabase get() {
        return ekoDatabase;
    }

    public abstract EkoHttpUrlDao httpUrlDao();

    public abstract EkoMqttUrlDao mqttUrlDao();

    public abstract AmityUploadUrlDao uploadUrlDao();

    public abstract EkoApiKeyDao apiKeyDao();

    public abstract EkoAccountDao accountDao();

    public abstract EkoFcmTokenDao fcmTokenDao();

    public abstract EkoBaiduTokenDao baiduTokenDao();

    public abstract EkoPushConfigDao pushConfigDao();
}

==> amity-sdk-7.15.0-sources.jar: main/com/ekoapp/ekosdk/internal/data/EkoDatabase.java <==
package com.ekoapp.ekosdk.internal.data;

import android.content.Context;

import androidx.room.Database;
import androidx.room.TypeConverters;

import com.amity.socialcloud.sdk.api.core.encryption.AmityDBEncryption;
import com.amity.socialcloud.sdk.infra.db.DBEncryptionUtils;
import com.amity.socialcloud.sdk.log.AmityLog;
import com.ekoapp.ekosdk.internal.data.converter.DateTimeTypeConverter;
import com.ekoapp.ekosdk.internal.data.converter.EkoPushConfigStateConverter;
import com.ekoapp.ekosdk.internal.data.dao.AmityUploadUrlDao;
import com.ekoapp.ekosdk.internal.data.dao.EkoAccountDao;
import com.ekoapp.ekosdk.internal.data.dao.EkoApiKeyDao;
import com.ekoapp.ekosdk.internal.data.dao.EkoBaiduTokenDao;
import com.ekoapp.ekosdk.internal.data.dao.EkoFcmTokenDao;
import com.ekoapp.ekosdk.internal.data.dao.EkoHttpUrlDao;
import com.ekoapp.ekosdk.internal.data.dao.EkoMqttUrlDao;
import com.ekoapp.ekosdk.internal.data.dao.EkoPushConfigDao;
import com.ekoapp.ekosdk.internal.data.model.AmityUploadUrl;
import com.ekoapp.ekosdk.internal.data.model.EkoAccount;
import com.ekoapp.ekosdk.internal.data.model.EkoApiKey;
import com.ekoapp.ekosdk.internal.data.model.EkoBaiduToken;
import com.ekoapp.ekosdk.internal.data.model.EkoFcmToken;
import com.ekoapp.ekosdk.internal.data.model.EkoHttpUrl;
import com.ekoapp.ekosdk.internal.data.model.EkoMqttUrl;
import com.ekoapp.ekosdk.internal.data.model.EkoPushConfig;
import com.ekoapp.ekosdk.internal.data.migration.EkoDatabaseMigrations;

import java.io.File;

@Database(
        version = 12,
        entities = {
                EkoAccount.class,
                EkoApiKey.class,
                EkoFcmToken.class,
                EkoBaiduToken.class,
                EkoPushConfig.class,
                EkoHttpUrl.class,
                EkoMqttUrl.class,
                AmityUploadUrl.class
        })
@TypeConverters({
        EkoPushConfigStateConverter.class,
        DateTimeTypeConverter.class
})
public abstract class EkoDatabase extends BaseRoomDatabase {

    private static EkoDatabase ekoDatabase;
    private static final String AUTH_DB_NAME = "eko";

    public static synchronized void init(
            Context context,
            AmityDBEncryption dbEncryption
    ) {
        final File dbFile = context.getDatabasePath(AUTH_DB_NAME);
        final DBEncryptionUtils.State state =  DBEncryptionUtils.INSTANCE.getDatabaseState(context, dbFile);

        if (dbEncryption instanceof AmityDBEncryption.AUTH
                || dbEncryption instanceof AmityDBEncryption.ALL) {

            if(state == DBEncryptionUtils.State.ENCRYPTED) {
                final boolean hasCorrectPassPhrase =
                        DBEncryptionUtils.INSTANCE.isPassPhraseCorrect(context, dbFile, dbEncryption.getAuthDBKey());
                if(!hasCorrectPassPhrase) {
                    AmityLog.INSTANCE.tag("amityEncryption").d("re-creating auth file with new key");
                    dbFile.delete();
                }
            } else if(state == DBEncryptionUtils.State.UNENCRYPTED) {
                AmityLog.INSTANCE.tag("amityEncryption").d("re-creating auth file with encryption");
                DBEncryptionUtils.INSTANCE.encrypt(context, dbFile, dbEncryption.getAuthDBKey());
            }

        } else { // case AmityDBEncryption.NONE
            if(state == DBEncryptionUtils.State.ENCRYPTED) {
                AmityLog.INSTANCE.tag("amityEncryption").d("re-creating auth file without encryption");
                dbFile.delete();
            } else if(state == DBEncryptionUtils.State.UNENCRYPTED && ekoDatabase != null) {
                // do not re-create database, if UNENCRYPTED db is already created
                return;
            }
        }

        ekoDatabase = BaseRoomDatabase.init(
                context,
                EkoDatabase.class,
                AUTH_DB_NAME,
                ekoDatabase,
                true,
                dbEncryption.getAuthDBKey(),
                EkoDatabaseMigrations.getAllMigrations(),
                EkoDatabaseMigrations.FIRST_MIGRATION_VERSION
        );
    }

    public static EkoDatabase get() {
        return ekoDatabase;
    }

    public abstract EkoHttpUrlDao httpUrlDao();

    public abstract EkoMqttUrlDao mqttUrlDao();

    public abstract AmityUploadUrlDao uploadUrlDao();

    public abstract EkoApiKeyDao apiKeyDao();

    public abstract EkoAccountDao accountDao();

    public abstract EkoFcmTokenDao fcmTokenDao();

    public abstract EkoBaiduTokenDao baiduTokenDao();

    public abstract EkoPushConfigDao pushConfigDao();
}
